@@ -6,9 +6,8 @@ from .. import Provider as DateTimeProvider
 
 class Provider(DateTimeProvider):
 
-    @classmethod
-    def day_of_week(cls):
-        day = cls.date('%w')
+    def day_of_week(self):
+        day = self.date('%w')
         DAY_NAMES = {
             "0": "Воскресенье",
             "1": "Понедельник",
@@ -20,9 +19,8 @@ class Provider(DateTimeProvider):
         }
         return DAY_NAMES[day]
 
-    @classmethod
-    def month_name(cls):
-        month = cls.month()
+    def month_name(self):
+        month = self.month()
         MONTH_NAMES = {
             "01": "Январь",
             "02": "Февраль",
@@ -38,4 +36,3 @@ class Provider(DateTimeProvider):
             "12": "Декабрь",
         }
         return MONTH_NAMES[month]
-
